@@ -1,7 +1,8 @@
-from datasets import load_dataset
-from hydra.utils import instantiate
 from omegaconf import DictConfig, open_dict
 
+from datasets import load_dataset
+from fusion_bench.utils import instantiate
+
 from .clip_dataset import CLIPDataset
 
 
