@@ -25,10 +25,9 @@ from torch.utils.data import DataLoader
 from transformers import CLIPModel, CLIPProcessor
 
 from fusion_bench.dataset import CLIPDataset, load_dataset_from_config
-from fusion_bench.modelpool.huggingface_clip_vision import HuggingFaceClipVisionPool
+from fusion_bench.mixins import CLIPClassificationMixin
 from fusion_bench.models.hf_clip import HFCLIPClassifier
 from fusion_bench.tasks.clip_classification import get_classnames_and_templates
-from fusion_bench.tasks.clip_classification.clip_mixin import CLIPClassificationMixin
 from fusion_bench.utils import timeit_context
 
 from .layer_wise_adamerging import LayerWiseAdaMergingAlgorithm
@@ -40,7 +39,6 @@ class CLIPLayerWiseAdaMergingAlgorithm(
     CLIPClassificationMixin,
     LayerWiseAdaMergingAlgorithm,
 ):
-
     def on_test_time_adaptation_start(self):
         """
         Here we load the CLIP processor and construct the zero-shot classification head for each task.
